@@ -90,6 +90,14 @@ class SmartWeather:
         """Returns station Weather Forecast."""
         return await self._forecast_data(forecast_type, hours_to_show)
 
+    async def get_daily_forecast(self) -> None:
+        """Returns station Weather Forecast."""
+        return await self._forecast_data(FORECAST_TYPE_DAILY, 0)
+
+    async def get_hourly_forecast(self) -> None:
+        """Returns station Weather Forecast."""
+        return await self._forecast_data(FORECAST_TYPE_HOURLY, 72)
+
     async def get_units(self) -> None:
         """Returns the units used for Values."""
         if self._to_units == UNIT_SYSTEM_METRIC:
@@ -294,6 +302,11 @@ class SmartWeather:
         else:
             cnt = 0
             for row in forecast[FORECAST_TYPE_HOURLY]:
+                # Skip over past forecasts - seems the API sometimes returns old forecasts
+                forecast_time = datetime.fromtimestamp(row["time"])
+                if today > forecast_time:
+                    continue
+
                 item = {
                     "timestamp": datetime.fromtimestamp(row["time"]),
                     "conditions": row["conditions"],
@@ -318,7 +331,7 @@ class SmartWeather:
                     "current_icon": current_icon,
                 }
                 items.append(ForecastDataHourly(item))
-                # Only take the first 24 hours
+                # Limit number of Hours
                 cnt += 1
                 if cnt >= hours_to_show:
                     break
